@@ -18,12 +18,14 @@ Readonly my $HALF       => 0.5;
 my $EMPTY         = q{};
 my $SPACE         = q{ };
 my $DOUBLE_QUOTES = q{"};
+my $BBOX_REGEX    = qr{(\d+)\s+(\d+)\s+(\d+)\s+(\d+)}xsm;
+my $HILITE_REGEX  = qr{[(]hilite\s+[#][A-Fa-f\d]{6}[)]\s+[(]xor[)]}xsm;
 
 BEGIN {
     use Exporter ();
     our ( $VERSION, @EXPORT_OK, %EXPORT_TAGS );
 
-    $VERSION = '2.11.0';
+    $VERSION = '2.12.6';
 
     use base qw(Exporter);
     %EXPORT_TAGS = ();    # eg: TAG => [ qw!name1 name2! ],
@@ -138,6 +140,15 @@ sub _hocr2boxes {
                         when (/_par$/xsm) {
                             $data->{type} = 'para';
                         }
+                        when (/_header$/xsm) {
+                            $data->{type} = 'header';
+                        }
+                        when (/_footer$/xsm) {
+                            $data->{type} = 'footer';
+                        }
+                        when (/_caption$/xsm) {
+                            $data->{type} = 'caption';
+                        }
                         when (/_line$/xsm) {
                             $data->{type} = 'line';
                         }
@@ -212,7 +223,7 @@ sub _hocr2boxes {
 
 sub _parse_tag_data {
     my ( $title, $data ) = @_;
-    if ( $title =~ /\bbbox\s+(\d+)\s+(\d+)\s+(\d+)\s+(\d+)/xsm ) {
+    if ( $title =~ /\bbbox\s+$BBOX_REGEX/xsm ) {
         if ( $1 != $3 and $2 != $4 ) { $data->{bbox} = [ $1, $2, $3, $4 ] }
     }
     if ( $title =~ /\btextangle\s+(\d+)/xsm ) { $data->{textangle}  = $1 }
@@ -277,7 +288,7 @@ sub _walk_bboxes {
     return;
 }
 
-sub to_djvu {
+sub to_djvu_txt {
     my ($self) = @_;
     my $string = $EMPTY;
     my ( $prev_depth, $h );
@@ -287,12 +298,20 @@ sub to_djvu {
             while ( $prev_depth-- >= $bbox->{depth} ) { $string .= ')' }
         }
         $prev_depth = $bbox->{depth};
-        if ( $bbox->{type} eq 'page' ) { $h = $bbox->{bbox}[-1] }
+        my $type = $bbox->{type};
+        if ( $type !~ /^(?:page|column|para|line|word)$/xsm ) {
+            if ( $bbox->{id} =~ /([[:alpha:]]+)/xsm ) {
+                $type = $1;
+            }
+            else {
+                $type = 'line';
+            }
+        }
+        if ( $type eq 'page' ) { $h = $bbox->{bbox}[-1] }
         my ( $x1, $y1, $x2, $y2 ) = @{ $bbox->{bbox} };
         if ( $bbox->{depth} != 0 ) { $string .= "\n" }
         for ( 1 .. $bbox->{depth} * 2 ) { $string .= $SPACE }
-        $string .= sprintf "($bbox->{type} %d %d %d %d", $x1, $h - $y2, $x2,
-          $h - $y1;
+        $string .= sprintf "($type %d %d %d %d", $x1, $h - $y2, $x2, $h - $y1;
         if ( defined $bbox->{text} ) {
             $string .=
                 $SPACE
@@ -308,6 +327,57 @@ sub to_djvu {
     return $string;
 }
 
+sub to_djvu_ann {
+    my ($self) = @_;
+    my $string = $EMPTY;
+    my $h;
+    my $iter = $self->get_bbox_iter();
+    while ( my $bbox = $iter->() ) {
+        if ( $bbox->{type} eq 'page' ) { $h = $bbox->{bbox}[-1] }
+        if ( defined $bbox->{text} ) {
+            my ( $x1, $y1, $x2, $y2 ) = @{ $bbox->{bbox} };
+            $string .=
+              sprintf
+              "(maparea \"\" \"%s\" (rect %d %d %d %d) (hilite #%s) (xor))\n",
+              _escape_text( $bbox->{text} ), $x1, $h - $y2, $x2 - $x1,
+              $y2 - $y1, $Gscan2pdf::Document::ANNOTATION_COLOR;
+        }
+    }
+    return $string;
+}
+
+sub from_djvu_ann {
+    my ( $self, $djvuann, $imagew, $imageh ) = @_;
+    push @{$self},
+      {
+        type  => 'page',
+        bbox  => [ 0, 0, $imagew, $imageh, ],
+        depth => 0,
+      };
+    for my $line ( split /\n/xsm, $djvuann ) {
+        if (
+            $line =~ m{[(]maparea\s+".*" # url
+\s+"(.*)" # text field enclosed in inverted commas
+\s+[(]rect\s+$BBOX_REGEX[)] # bounding box
+\s+$HILITE_REGEX # highlight color
+[)]}xsm
+          )
+        {
+            push @{$self},
+              {
+                type  => 'word',
+                depth => 1,
+                text  => $1,
+                bbox  => [ $2, $imageh - $3 - $5, $2 + $4, $imageh - $3 ]
+              };
+        }
+        else {
+            croak "Error parsing djvu annotation $line";
+        }
+    }
+    return;
+}
+
 # Escape backslashes and inverted commas
 sub _escape_text {
     my ($txt) = @_;
@@ -339,14 +409,12 @@ sub to_text {
     return $string;
 }
 
-sub from_djvu {
+sub from_djvu_txt {
     my ( $self, $djvutext ) = @_;
     my $h;
     my $depth = 0;
     for my $line ( split /\n/xsm, $djvutext ) {
-        if ( $line =~
-            /^\s*([(]+)(\w+)\s+(\d+)\s+(\d+)\s+(\d+)\s+(\d+)(.*?)([)]*)$/xsm )
-        {
+        if ( $line =~ /^\s*([(]+)(\w+)\s+$BBOX_REGEX(.*?)([)]*)$/xsm ) {
             my %bbox;
             $depth += length $1;
             $bbox{depth} = $depth - 1;
@@ -484,56 +552,7 @@ EOS
     my ( $prev_depth, @tags );
     my $iter = $self->get_bbox_iter();
     while ( my $bbox = $iter->() ) {
-        if ( defined $prev_depth ) {
-            if ( $prev_depth >= $bbox->{depth} ) {
-                while ( $prev_depth-- >= $bbox->{depth} ) {
-                    $string .= '</' . pop(@tags) . ">\n";
-                }
-            }
-            else {
-                $string .= "\n";
-            }
-        }
-        $prev_depth = $bbox->{depth};
-        my ( $x1, $y1, $x2, $y2 ) = @{ $bbox->{bbox} };
-        my $type = 'ocr_' . $bbox->{type};
-        my $tag  = 'span';
-        given ( $bbox->{type} ) {
-            when ('page') {
-                $tag = 'div';
-            }
-            when (/^(?:carea|column)$/xsm) {
-                $type = 'ocr_carea';
-                $tag  = 'div';
-            }
-            when ('para') {
-                $type = 'ocr_par';
-                $tag  = 'p';
-            }
-        }
-        $string .= $SPACE x ( 2 + $bbox->{depth} ) . "<$tag class='$type'";
-        if ( defined $bbox->{id} ) { $string .= " id='$bbox->{id}'" }
-        $string .= " title='bbox $x1 $y1 $x2 $y2";
-        if ( defined $bbox->{confidence} ) {
-            $string .= "; x_wconf $bbox->{confidence}";
-        }
-        $string .= "'>";
-        if ( defined $bbox->{text} ) {
-            if ( defined $bbox->{style} ) {
-                for my $tag ( @{ $bbox->{style} } ) {
-                    if    ( $tag eq 'Bold' )   { $string .= '<strong>' }
-                    elsif ( $tag eq 'Italic' ) { $string .= '<em>' }
-                }
-            }
-            $string .= HTML::Entities::encode( $bbox->{text}, "<>&\"'" );
-            if ( defined $bbox->{style} ) {
-                for my $tag ( reverse @{ $bbox->{style} } ) {
-                    if    ( $tag eq 'Bold' )   { $string .= '</strong>' }
-                    elsif ( $tag eq 'Italic' ) { $string .= '</em>' }
-                }
-            }
-        }
-        push @tags, $tag;
+        $string .= _bbox_to_hocr( $bbox, \$prev_depth, \@tags );
     }
     if (@tags) { $string .= '</' . pop(@tags) . ">\n" }
     $prev_depth--;
@@ -544,6 +563,71 @@ EOS
     return $string;
 }
 
+sub _bbox_to_hocr {
+    my ( $bbox, $prev_depth, $tags ) = @_;
+    my $string = q{};
+    if ( defined ${$prev_depth} ) {
+        if ( ${$prev_depth} >= $bbox->{depth} ) {
+            if ( @{$tags} ) { $string .= '</' . pop( @{$tags} ) . ">\n" }
+            ${$prev_depth}--;
+            while ( ${$prev_depth}-- >= $bbox->{depth} ) {
+                $string .= $SPACE x ( 2 + ${$prev_depth} + 1 ) . '</'
+                  . pop( @{$tags} ) . ">\n";
+            }
+        }
+        else {
+            $string .= "\n";
+        }
+    }
+    ${$prev_depth} = $bbox->{depth};
+    my ( $x1, $y1, $x2, $y2 ) = @{ $bbox->{bbox} };
+    my $type = 'ocr_' . $bbox->{type};
+    my $tag  = 'span';
+    given ( $bbox->{type} ) {
+        when ('page') {
+            $tag = 'div';
+        }
+        when (/^(?:carea|column)$/xsm) {
+            $type = 'ocr_carea';
+            $tag  = 'div';
+        }
+        when ('para') {
+            $type = 'ocr_par';
+            $tag  = 'p';
+        }
+    }
+    $string .= $SPACE x ( 2 + $bbox->{depth} ) . "<$tag class='$type'";
+    if ( defined $bbox->{id} ) { $string .= " id='$bbox->{id}'" }
+    $string .= " title='bbox $x1 $y1 $x2 $y2";
+    if ( defined $bbox->{baseline} ) {
+        $string .= '; baseline ' . join $SPACE, @{ $bbox->{baseline} };
+    }
+    if ( defined $bbox->{textangle} ) {
+        $string .= "; textangle $bbox->{textangle}";
+    }
+    if ( defined $bbox->{confidence} ) {
+        $string .= "; x_wconf $bbox->{confidence}";
+    }
+    $string .= "'>";
+    if ( defined $bbox->{text} ) {
+        if ( defined $bbox->{style} ) {
+            for my $tag ( @{ $bbox->{style} } ) {
+                if    ( $tag eq 'Bold' )   { $string .= '<strong>' }
+                elsif ( $tag eq 'Italic' ) { $string .= '<em>' }
+            }
+        }
+        $string .= HTML::Entities::encode( $bbox->{text}, "<>&\"'" );
+        if ( defined $bbox->{style} ) {
+            for my $tag ( reverse @{ $bbox->{style} } ) {
+                if    ( $tag eq 'Bold' )   { $string .= '</strong>' }
+                elsif ( $tag eq 'Italic' ) { $string .= '</em>' }
+            }
+        }
+    }
+    push @{$tags}, $tag;
+    return $string;
+}
+
 sub crop {
     my ( $self, $x, $y, $w, $h ) = @_;
     my $i = 0;
