@@ -18,7 +18,7 @@ BEGIN {
     use Exporter ();
     our ( $VERSION, @EXPORT_OK, %EXPORT_TAGS );
 
-    $VERSION = '2.11.0';
+    $VERSION = '2.12.6';
 
     use base qw(Exporter);
     %EXPORT_TAGS = ();              # eg: TAG => [ qw!name1 name2! ],
@@ -533,7 +533,7 @@ sub get_option {
                 }
             }
             when ('CheckButton') {
-                return $hashref->{$option}{widget}->get_active ? TRUE : FALSE;
+                return $hashref->{$option}{widget}->get_active;
             }
             when ('SpinButton') {
                 return $hashref->{$option}{widget}->get_value;
